@@ -75,6 +75,15 @@ bool Target::existField (QString name) {
 	}
 	return false;
 }
+
+int Target::getFieldByName (QString name) {
+	for (int i = 0; i < this->fields.size(); i++) {
+		TargetField * field = this->fields.at(i);
+		if (field->name == name) return i;
+	}
+	return -1;
+}
+
 QString Target::getSummary () {
 	return this->type;
 }
