@@ -800,13 +800,17 @@ void DetailWindow::exportCardFace()
 {
 	if (target->picture != NULL) {
 		QString path(QDesktopServices::storageLocation(QDesktopServices::PicturesLocation));
+
+		path.append("/").append(target->name.simplified().replace(' ', '_')).append(".png");
+
 		QString s = QFileDialog::getSaveFileName(
 	                this,
 	                tr("Choose card face image file"),
 	                path,
 	                tr("Images (*.png);;"));
 		if (!s.isNull () && !s.isEmpty ()) {
-			s.append(".png");
+			if (!s.endsWith(".png"))
+				s.append(".png");
 			target->picture->save(s, "PNG"); // writes image into ba in PNG format
 		}
 	}
@@ -938,13 +942,17 @@ void DetailWindow::exportCardBack()
 {
 	if (target->pictureBack != NULL) {
 		QString path(QDesktopServices::storageLocation(QDesktopServices::PicturesLocation));
+
+		path.append("/").append(target->name.simplified().replace(' ', '_')).append("_BACK.png");
+
 		QString s = QFileDialog::getSaveFileName(
 	                this,
 	                tr("Choose card back image file"),
 	                path,
 	                tr("Images (*.png);;"));
 		if (!s.isNull () && !s.isEmpty ()) {
-			s.append(".png");
+			if (!s.endsWith(".png"))
+				s.append(".png");
 			target->pictureBack->save(s, "PNG"); // writes image into ba in PNG format
 		}
 	}
