@@ -41,6 +41,8 @@ private:
 	QPushButton * previousButton;
 	QPushButton * nextButton;
 	QPushButton * deleteButton;
+	QList<TargetField*> fields;
+	bool _fieldsChanged;
 };
 
 
@@ -57,6 +59,7 @@ public:
 
 private:
 	int pos;
+	int elType;
 	eWallet * parent;
 	
 	QLabel * imageLabel;
@@ -129,7 +132,8 @@ signals:
 	void editTarget(Target * source);
 	void newLikeTarget(Target * source);
 	void duplicateTarget(Target * source);
-
+public:
+	bool fieldsChanged;
 };
 
 class ButtonInfo: public QObjectUserData {
