@@ -1399,6 +1399,9 @@ void eWallet::contextMenuEvent (QContextMenuEvent * event) {
 
 void eWallet::exportData() {
 	QString path(QDesktopServices::storageLocation(QDesktopServices::HomeLocation));
+
+	path.append("/wallet_export.txt");
+
 	QString s = QFileDialog::getSaveFileName(
 	                this,
 	                tr("Choose export file"),
@@ -1407,6 +1410,9 @@ void eWallet::exportData() {
 
 	this->setAttribute(Qt::WA_Maemo5ShowProgressIndicator, true);
 	if (!s.isNull () && !s.isEmpty ()) {
+		if (!s.endsWith(".txt"))
+			s.append(".txt");
+
 		  QFile file(s);
 
 		  if ( file.open(QIODevice::Text | QIODevice::WriteOnly) ) {
